@@ -108,7 +108,7 @@ class Event(SimpleTranslationMixin, models.Model):
 
     placeholders = M2MPlaceholderField(
         actions=SimpleTranslationPlaceholderActions(),
-        placeholders=('conference', ),
+        placeholders=('conference', 'detailed_description'),
     )
 
     # Allow null for once but remove this later, when data is setup.
